<?php
/**
 * Blackbird ContentManager Module
 *
 * NOTICE OF LICENSE
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@bird.eu so we can send you a copy immediately.
 *
 * @category            Blackbird
 * @package		Blackbird_ContentManager
 * @copyright           Copyright (c) 2016 Blackbird (http://black.bird.eu)
 * @author		Blackbird Team
 * @license		http://www.advancedcontentmanager.com/license/
 */
namespace Blackbird\ContentManager\Block\Adminhtml\Content\Widget;

use Magento\Backend\Block\Template;
use Magento\Framework\Data\Form\Element\AbstractElement;
use Magento\Framework\Data\Form\Element\Renderer\RendererInterface;

/**
 * Class Conditions
 */
class Conditions extends Template implements RendererInterface
{
    /**
     * @var \Magento\Rule\Block\Conditions
     */
    protected $_conditions;

    /**
     * @var \Blackbird\ContentManager\Model\Rule
     */
    protected $_rule;

    /**
     * @var \Magento\Framework\Data\Form\Element\Factory
     */
    protected $_elementFactory;

    /**
     * @var \Magento\Framework\Registry
     */
    protected $_coreRegistry;

    /**
     * @var AbstractElement
     */
    protected $_element;

    /**
     * @var \Magento\Framework\Data\Form\Element\Text
     */
    protected $_input;

    /**
     * @var string
     */
    protected $_template = 'content/widget/conditions.phtml';

    /**
     * @var \Magento\Widget\Helper\Conditions
     */
    protected $conditionsHelper;

    /**
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Framework\Data\Form\Element\Factory $elementFactory
     * @param \Magento\Rule\Block\Conditions $conditions
     * @param \Blackbird\ContentManager\Model\Rule $rule
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Widget\Helper\Conditions $conditionsHelper
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Data\Form\Element\Factory $elementFactory,
        \Magento\Rule\Block\Conditions $conditions,
        \Blackbird\ContentManager\Model\Rule $rule,
        \Magento\Framework\Registry $registry,
        \Magento\Widget\Helper\Conditions $conditionsHelper,
        array $data = []
    ) {
        $this->_elementFactory = $elementFactory;
        $this->_conditions = $conditions;
        $this->_rule = $rule;
        $this->_coreRegistry = $registry;
        $this->conditionsHelper = $conditionsHelper;
        parent::__construct($context, $data);
    }

    /**
     * {@inheritdoc}
     */
    protected function _construct()
    {
        $widgetInstance = $this->_widgetFactory->create();
        $widgetInstance->load($this->getRequest()->getParam('instance_id'));
        $widgetParam = $widgetInstance->getWidgetParameters();
        $cond = $widgetParam["conditions"];
        $this->_rule->loadPost(array('conditions' => $cond));
        
        // olde bugged code
//        $widgetParams = $this->getRequest()->getParam('widget');
//        if ($widgetParams)
//        {
//            $widgetParams = json_decode($widgetParams);
//            if ($widgetParams && isset($widgetParams->values) && isset($widgetParams->values->conditions_encoded)) {
//                $conditionsDecodedWidget = $this->getConditionsDecoded($widgetParams->values->conditions_encoded);
//                $this->_rule->loadPost(array('conditions' => $conditionsDecodedWidget));
//            }
//        }
    }

    /**
     * @return \Magento\Rule\Model\Condition\Combine
     */
    protected function getConditionsDecoded($conditionsEncoded)
    {
        $conditions = $this->conditionsHelper->decode($conditionsEncoded);
        return $conditions;
    }

    /**
     * {@inheritdoc}
     */
    public function render(AbstractElement $element)
    {
        $this->_element = $element;
        return $this->toHtml();
    }

    /**
     * @return string
     */
    public function getNewChildUrl()
    {
        return $this->getUrl(
            'contentmanager/content_widget/conditions/form' . $this->getElement()->getContainer()->getHtmlId() 
        );
    }

    /**
     * @return AbstractElement
     */
    public function getElement()
    {
        return $this->_element;
    }

    /**
     * @return string
     */
    public function getHtmlId()
    {
        return $this->getElement()->getContainer()->getHtmlId();
    }

    /**
     * @return string
     */
    public function getInputHtml()
    {
        $this->_input = $this->_elementFactory->create('text');
        $this->_input
                ->setRule($this->_rule)
                ->setValues()
                ->setRenderer($this->_conditions);
        
        return $this->_input->toHtml();
    }
}
